Index: src/lib/codecs/speex/filters/dsfSpeexEncoder/SpeexEncodeInputPin.cpp
===================================================================
--- src/lib/codecs/speex/filters/dsfSpeexEncoder/SpeexEncodeInputPin.cpp	(rvision 11936)
+++ src/lib/codecs/speex/filters/dsfSpeexEncoder/SpeexEncodeInputPin.cpp	(copie de travail)
@@ -32,6 +32,8 @@
 #include "stdafx.h"
 #include "SpeexEncodeInputPin.h"
 
+#define ADAPT_FRAME_RATE 1
+
 SpeexEncodeInputPin::SpeexEncodeInputPin(       AbstractTransformFilter* inParentFilter
                                             ,   CCritSec* inFilterLock
                                             ,   AbstractTransformOutputPin* inOutputPin
@@ -45,6 +47,8 @@
 	,	mWaveFormat(NULL)
     ,   mBegun(false)
 	,	mUptoFrame(0)
+
+	, timeStart(0), timeEnd(0)
 {
 
 }
@@ -54,9 +58,15 @@
 	DestroyCodec();
 }
 
+void SpeexEncodeInputPin::SetInputSampleTime(REFERENCE_TIME pTimeStart, REFERENCE_TIME pTimeEnd)
+{
+	timeStart = pTimeStart/10000;
+	timeEnd = pTimeEnd/10000;
+}
+
 HRESULT SpeexEncodeInputPin::TransformData(unsigned char* inBuf, long inNumBytes) 
 {
-    HRESULT locHR = S_OK;
+	HRESULT locHR = S_OK;
     vector<StampedOggPacket*> locPackets;
     if (!mBegun) {
         locPackets = mSpeexEncoder.setupCodec(mEncoderSettings);
@@ -80,11 +90,26 @@
     unsigned long locNumSamplesPerChannel = bufferBytesToSampleCount(inNumBytes);
     locPackets = mSpeexEncoder.encode((const short* const)inBuf, locNumSamplesPerChannel);
 
+	/* TODO: skip packet if we are too late ? */
+
     locHR = sendPackets(locPackets);
-    deletePacketsAndEmptyVector(locPackets);
+	deletePacketsAndEmptyVector(locPackets);
+
+#ifdef ADAPT_FRAME_RATE
+	/* Resend same packet if we are too early */
+	if (!FAILED(locHR)) {
+		__int64 curTime = (timeStart*mEncoderSettings.sampleRate())/1000;
+		while (curTime-mUptoFrame > locNumSamplesPerChannel) {
+		    locPackets = mSpeexEncoder.encode((const short* const)inBuf, locNumSamplesPerChannel);
+			locHR = sendPackets(locPackets);
+			deletePacketsAndEmptyVector(locPackets);
+		}
+	}
+#endif
+
     return locHR;
+}
 
-}
 bool SpeexEncodeInputPin::ConstructCodec() 
 {
 
Index: src/lib/codecs/speex/filters/dsfSpeexEncoder/SpeexEncodeInputPin.h
===================================================================
--- src/lib/codecs/speex/filters/dsfSpeexEncoder/SpeexEncodeInputPin.h	(rvision 11936)
+++ src/lib/codecs/speex/filters/dsfSpeexEncoder/SpeexEncodeInputPin.h	(copie de travail)
@@ -70,5 +70,6 @@
     SpeexEncoder mSpeexEncoder;
     SpeexEncodeSettings mEncoderSettings;
 
-
+	unsigned __int64 timeStart, timeEnd;
+	void SetInputSampleTime(REFERENCE_TIME pTimeStart, REFERENCE_TIME pTimeEnd);	
 };